@@ -83,11 +83,11 @@ create_marker_layer (G_GNUC_UNUSED ChamplainView *view, ChamplainPathLayer **pat
 {
 	ClutterActor *marker;
 	ClutterActor *layer_actor;
-	ClutterColor city_color = {0x35, 0x84, 0xE4, 0xFF};
-	ClutterColor city_a_color = {0x57, 0xE3, 0x89, 0xFF};
-	ClutterColor city_b_color = {0xF6, 0xD3, 0x2D, 0xFF};
-	ClutterColor city_c_color = {0xB1, 0x92, 0xF6, 0xFF};
-	ClutterColor city_d_color = {0xF6, 0x7D, 0xA3, 0xFF};
+	ClutterColor city_color = {0xdd, 0x56, 0xb5, 0xFF};
+	ClutterColor city_a_color = {0x19, 0x4c, 0xb5, 0xFF};
+	ClutterColor city_b_color = {0x4c, 0x8b, 0x5e, 0xFF};
+	ClutterColor city_c_color = {0x22, 0x45, 0xb6, 0xFF};
+	ClutterColor city_d_color = {0x0f, 0x2d, 0x75, 0xFF};
 	ClutterColor city_e_color = {0x35, 0x84, 0xE4, 0xFF};
 	ClutterColor text_color = {0xFF, 0xFF, 0xFF, 0xFF};
 	LocationCallbackData callback_data;
